pub struct SimplifiedCommand {
pub original: String,
pub result: String,
pub truncate: bool,
}Fields
original: Stringresult: Stringtruncate: boolImplementations
Sourceimpl SimplifiedCommand
The goal of SimplifiedCommand is to produce a reduced approximation of the given command for template matching. It may
not produce an exact simplification. (For example, it does not handle deeply nested escaping, and it drops escape characters.)
Possible enhancements:
impl SimplifiedCommand
The goal of SimplifiedCommand is to produce a reduced approximation of the given command for template matching. It may not produce an exact simplification. (For example, it does not handle deeply nested escaping, and it drops escape characters.) Possible enhancements:
- Sort and expand command line options.
- Check to see if unknown strings represent valid local paths in the directory where the command was run.